***********
Display
***********

``import gouda.display``

Requirements
============

* `NumPy <https://github.com/numpy/numpy>`_
* `Matplotlib <https://matplotlib.org/>`_

Methods
=======

.. automodule:: gouda.display
   :members: print_grid, print_grid_v2
